import streamlit.components.v1 as components
import os

_RELEASE = False

if not _RELEASE:
    _component_func = components.declare_component(
        "token_craft",
        url="http://localhost:3000",  # This should match your development server's URL
    )
else:
    parent_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
    build_dir = os.path.join(parent_dir, "token_craft/frontend/build")
    _component_func = components.declare_component("token_craft", path=build_dir)


def st_token_table(tokens, column_visibility=None, key=None):
    # Set default visibility if none provided
    if column_visibility is None:
        column_visibility = {
            "name": True,
            "key": True,
            "dateCreated": True,
            "lastUsed": True,
            "actions": True,
        }
    return _component_func(tokens=tokens, columnVisibility=column_visibility, key=key)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="streamlit-token_craft",
    version="0.1.5",
    author="Stavros Theocharis",
    author_email="stavrostheocharis@yahoo.gr",
    description="streamlit custom token craft and management component",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/stavrostheocharis/streamlit-token-craft",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords=[
        "Python",
        "Streamlit",
        "React",
        "JavaScript",
        "token craft",
        "token manager",
    ],
    python_requires=">=3.9",
    install_requires=[
        "streamlit >= 1.29.0",
    ],
)
